

'use strict';
{
  const globals = this;
  const django = globals.django || (globals.django = {});

  
  django.pluralidx = function(n) {
    const v = (n != 1);
    if (typeof v === 'boolean') {
      return v ? 1 : 0;
    } else {
      return v;
    }
  };
  

  /* gettext library */

  django.catalog = django.catalog || {};
  
  const newcatalog = {
    "(If left blank, owner will be admin)": "(Ha \u00fcresen marad akkor a tulajdonos lesz az admin)",
    "(current notification)": "(aktu\u00e1lis \u00e9rtes\u00edt\u00e9s)",
    "(current version)": "(aktu\u00e1lis verzi\u00f3)",
    "1 Year": "1 \u00e9v",
    "1 month ago": "1 h\u00f3napja",
    "1 week ago": "1 hete",
    "3 days ago": "3 napja",
    "30 Days": "30 nap",
    "7 Days": "7 nap",
    "A file with the same name already exists in this folder.": "A f\u00e1jl ezzel a n\u00e9vvel m\u00e1r l\u00e9tezik a k\u00f6nyvt\u00e1rban.",
    "About": "N\u00e9vjegy",
    "About Us": "N\u00e9vjegy",
    "Accept": "Elfogad",
    "Accepted": "Elfogadva",
    "Accepter": "Elfogad\u00f3",
    "Access Log": "Hozz\u00e1f\u00e9r\u00e9si napl\u00f3",
    "Action": "M\u0171velet",
    "Actions": "Tennival\u00f3k",
    "Activate user immediately after registration. If unchecked, a user need to be activated by administrator or via activation email": "Felhaszn\u00e1l\u00f3 automatikus aktiv\u00e1l\u00e1sa regisztr\u00e1ci\u00f3 ut\u00e1n. Amennyiben nincs bepip\u00e1lva, a felhaszn\u00e1l\u00f3t aktiv\u00e1lni kell egy adminisztr\u00e1tornak, vagy aktiv\u00e1l\u00f3 E-mail seg\u00edts\u00e9g\u00e9vel.",
    "Activated": "Aktiv\u00e1lva",
    "Activated Users": "Aktiv\u00e1lt felhaszn\u00e1l\u00f3k",
    "Active": "Akt\u00edv",
    "Active Users": "Bejelentkezett felhaszn\u00e1l\u00f3k",
    "Activities": "Tev\u00e9kenys\u00e9gek",
    "Add": "Hozz\u00e1ad",
    "Add Admins": "Adminisztr\u00e1torok hozz\u00e1ad\u00e1sa",
    "Add Library": "K\u00f6tet hozz\u00e1ad\u00e1sa",
    "Add Member": "Tag hozz\u00e1ad\u00e1sa",
    "Add Terms and Conditions": "Felhaszn\u00e1l\u00e1si felt\u00e9telek hozz\u00e1ad\u00e1sa",
    "Add User": "Felhaszn\u00e1l\u00f3 hozz\u00e1ad\u00e1sa",
    "Add admin": "Adminisztr\u00e1tor hozz\u00e1ad\u00e1sa",
    "Add auto expiration": "Automatikus lej\u00e1rat be\u00e1ll\u00edt\u00e1sa",
    "Add custom permission": "Egyedi jogosults\u00e1g hozz\u00e1ad\u00e1sa",
    "Add institution": "Int\u00e9zm\u00e9ny hozz\u00e1ad\u00e1sa",
    "Add new notification": "\u00daj \u00e9rtes\u00edt\u00e9s hozz\u00e1ad\u00e1sa",
    "Add password protection": "Jelsz\u00f3 v\u00e9delem hozz\u00e1ad\u00e1sa",
    "Add user": "Felhaszn\u00e1l\u00f3 hozz\u00e1ad\u00e1sa",
    "Added": "Hozz\u00e1adva",
    "Added user {user}": "Felhaszn\u00e1l\u00f3 hozz\u00e1adva: {user}",
    "Admin": "Adminisztr\u00e1tor",
    "Admin Login Logs": "Admin bejelentkez\u00e9si napl\u00f3",
    "Admin Logs": "Admin napl\u00f3",
    "Admin Operation Logs": "Admin m\u0171veletek napl\u00f3",
    "Admin access": "Admin hozz\u00e1f\u00e9r\u00e9s",
    "Admins": "Adminisztr\u00e1torok",
    "All": "Mind",
    "All Groups": "Minden csoport",
    "All Libraries": "\u00d6sszes k\u00f6tet",
    "All Notifications": "\u00d6sszes \u00e9rtes\u00edt\u00e9s",
    "All Public Links": "\u00d6sszes nyilv\u00e1nos link",
    "All file types": "Minden f\u00e1jl t\u00edpus",
    "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Regisztr\u00e1ci\u00f3k enged\u00e9lyez\u00e9se. Vegye ki a pip\u00e1t, hogy megakad\u00e1lyozza \u00faj felhaszn\u00e1l\u00f3k regisztr\u00e1l\u00e1s\u00e1t.",
    "Allow user to change library history settings": "Enged\u00e9lyezi a felhaszn\u00e1l\u00f3knak, a k\u00f6tetnapl\u00f3 be\u00e1ll\u00edt\u00e1sainak m\u00f3dos\u00edt\u00e1s\u00e1t.",
    "Allow user to clean library trash": "Enged\u00e9lyezi a felhaszn\u00e1l\u00f3nak a kuka \u00fcr\u00edt\u00e9s\u00e9t",
    "Allow user to create encrypted libraries": "Enged\u00e9lyezi a felhaszn\u00e1l\u00f3knak titkos\u00edtot k\u00f6tet l\u00e9trehoz\u00e1s\u00e1t.",
    "An integer that is greater than 0 or equal to -2.": "0-n\u00e1l nagyobb, vagy -2-vel egyenl\u0151 eg\u00e9sz sz\u00e1m.",
    "An integer that is greater than or equal to 0.": "0-n\u00e1l nagyobb vagy egyenl\u0151 eg\u00e9sz.",
    "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "A bels\u0151 link seg\u00edts\u00e9g\u00e9vel azon a felhaszn\u00e1l\u00f3k \u00e9rhetik el a f\u00e1jlt, vagy mapp\u00e1t, akik rendelkeznek olvas\u00e1si joggal az adott f\u00e1jlon, vagy mapp\u00e1n.",
    "Anonymous User": "Anonymous felhaszn\u00e1l\u00f3",
    "Are you sure to delete": "Biztosan t\u00f6rli?",
    "Are you sure you want to clear trash?": "Biztos, hogy \u00fcr\u00edti a kuk\u00e1t?",
    "Are you sure you want to delete %s ?": "Biztosan t\u00f6rli: %s?",
    "Are you sure you want to delete the selected user(s) ?": "Biztoson t\u00f6r\u00f6lni k\u00edv\u00e1nja a kijelelt felhaszn\u00e1l\u00f3(ka)t?",
    "Are you sure you want to delete the share link?": "Biztosan t\u00f6rli a megoszt\u00e1si linket?",
    "Are you sure you want to restore this library?": "Biztosan vissza\u00e1ll\u00edtja a k\u00f6tetet?",
    "Are you sure you want to unlink this device?": "Biztosan sz\u00e9tkapcsolja az eszk\u00f6zt?",
    "Audio": "Zene",
    "Audit Admin": "Vizsg\u00e1l\u00f3 Admin",
    "Avatar": "Avatar:",
    "Avatar:": "Avatar:",
    "Back": "Vissza",
    "Branding": "Branding",
    "Broken (please contact your administrator to fix this library)": "S\u00e9r\u00fclt (a k\u00f6tet jav\u00edt\u00e1sa \u00e9rdek\u00e9ben k\u00e9rem \u00e9rtes\u00edtse az adminisztr\u00e1tort)",
    "Can not copy directory %(src)s to its subdirectory %(des)s": "A(z) %(src)s k\u00f6nyvt\u00e1rat nem lehet \u00e1tm\u00e1solni a(z) %(des)s alk\u00f6nyvt\u00e1r\u00e1ba",
    "Can not move directory %(src)s to its subdirectory %(des)s": "A(z) %(src)s k\u00f6nyvt\u00e1rat nem lehet \u00e1tmozgatni a(z) %(des)s alk\u00f6nyvt\u00e1r\u00e1ba",
    "Cancel": "M\u00e9gsem",
    "Cancel All": "Mindet kivesz",
    "Change": "V\u00e1ltoztat\u00e1s",
    "Change Password": "Jelsz\u00f3 v\u00e1ltoztat\u00e1s",
    "Change Password of Library {placeholder}": "Jelsz\u00f3 megv\u00e1ltoztat\u00e1sa a k\u00f6tethez:  {placeholder}",
    "Changes": "V\u00e1ltoz\u00e1sok",
    "Clean": "T\u00f6r\u00f6l",
    "Clear": "Tiszt\u00edt",
    "Clear Trash": "Kuka \u00fcr\u00edt\u00e9se",
    "Clear files in trash and history\uff1a": "F\u00e1jlok t\u00f6rl\u00e9se a kuk\u00e1b\u00f3l \u00e9s az el\u0151zm\u00e9nyekb\u0151l :",
    "Clients": "Kliensek",
    "Close": "Bez\u00e1r\u00e1s",
    "Column": "Oszlop",
    "Community Edition": "K\u00f6z\u00f6ss\u00e9gi verzi\u00f3",
    "Confirm Password": "Jelsz\u00f3 meger\u0151s\u00edt\u00e9se",
    "Contact Email": "Kapcsolat email",
    "Contact Email:": "Kapcsolat email:",
    "Copy": "M\u00e1sol\u00e1s",
    "Copy selected item(s) to:": "Kiv\u00e1lasztott elem(ek) m\u00e1sol\u00e1sa ide:",
    "Count": "Sz\u00e1ml\u00e1l\u00f3",
    "Create": "L\u00e9trehoz\u00e1s",
    "Create Group": "Csoport l\u00e9trehoz\u00e1sa",
    "Create Library": "K\u00f6tet l\u00e9trehoz\u00e1sa",
    "Create Report": "Jelent\u00e9s k\u00e9sz\u00edt\u00e9se",
    "Create a draft from this file, instead of editing it directly.": "Piszkozat l\u00e9trehoz\u00e1sa a f\u00e1jlb\u00f3l szerkeszt\u00e9s helyett.",
    "Created": "L\u00e9trehozva",
    "Created At": "L\u00e9trehozva",
    "Created Files": "L\u00e9trehozott f\u00e1jlok",
    "Created draft": "L\u00e9trehozott piszkozat",
    "Created file": "L\u00e9trehozott f\u00e1jl",
    "Created folder": "L\u00e9trehozott mappa",
    "Created group {group_name}": "Csoport l\u00e9trehozva: {group_name}",
    "Created library": "K\u00f6tet l\u00e9trehozva",
    "Created library {library_name} with {owner} as its owner": "{library_name} l\u00e9trehozva. Tulajdonos: {owner}",
    "Creator": "L\u00e9trehoz\u00f3",
    "Current Connected Devices": "Csatlakozott eszk\u00f6z\u00f6k",
    "Current Library": "Aktu\u00e1lis k\u00f6tet",
    "Current Path: ": "Aktu\u00e1lis \u00fatvonal: ",
    "Current Version": "Aktu\u00e1lis verzi\u00f3",
    "Current path: ": "Aktu\u00e1lis \u00fatvonal: ",
    "Custom CSS": "Egy\u00e9ni CSS",
    "Custom file types": "Egyedi f\u00e1jlt\u00edpusok",
    "Daily Admin": "Napi Admin",
    "Database": "Adatb\u00e1zis",
    "Date": "D\u00e1tum",
    "Default": "Alap\u00e9rtelmezett",
    "Default Admin": "Alap\u00e9rtelmezett Admin",
    "Delete": "T\u00f6rl\u00e9s",
    "Delete Account": "Fi\u00f3k t\u00f6rl\u00e9se",
    "Delete Department": "Oszt\u00e1ly t\u00f6rl\u00e9se",
    "Delete Expired Invitations": "Lej\u00e1rt megh\u00edvok t\u00f6rl\u00e9se",
    "Delete File": "F\u00e1jl t\u00f6rl\u00e9se",
    "Delete Folder": "Mappa t\u00f6rl\u00e9se",
    "Delete Group": "Csoport t\u00f6rl\u00e9se",
    "Delete Institution": "Int\u00e9zm\u00e9ny t\u00f6rl\u00e9se",
    "Delete Library": "K\u00f6tet t\u00f6rl\u00e9se",
    "Delete Member": "Tag elt\u00e1vol\u00edt\u00e1sa",
    "Delete Notification": "\u00c9rtes\u00edt\u00e9s t\u00f6rl\u00e9se",
    "Delete Organization": "Szervezet t\u00f6rl\u00e9se",
    "Delete Time": "T\u00f6rl\u00e9s ideje",
    "Delete User": "Felhaszn\u00e1l\u00f3 t\u00f6rl\u00e9se",
    "Delete draft": "V\u00e1zlat t\u00f6rl\u00e9se",
    "Delete files from this device the next time it comes online.": "T\u00f6r\u00f6lje a f\u00e1jlokat az eszk\u00f6zr\u0151l, amikor legk\u00f6zelebb online lesz.",
    "Deleted": "T\u00f6r\u00f6lve",
    "Deleted Libraries": "T\u00f6r\u00f6lt k\u00f6tetek",
    "Deleted Time": "T\u00f6rl\u00e9s ideje",
    "Deleted directories": "T\u00f6r\u00f6lt k\u00f6nyvt\u00e1rak",
    "Deleted draft": "T\u00f6r\u00f6lt piszkozat",
    "Deleted file": "T\u00f6r\u00f6lt f\u00e1jl",
    "Deleted files": "T\u00f6r\u00f6lt f\u00e1jlok",
    "Deleted folder": "T\u00f6r\u00f6lt mappa",
    "Deleted group {group_name}": "Csoport t\u00f6r\u00f6lve: {group_name}",
    "Deleted library": "T\u00f6r\u00f6lt k\u00f6tet",
    "Deleted library {library_name}": "{library_name} k\u00f6tet t\u00f6r\u00f6lve",
    "Deleted user {user}": "Felhaszn\u00e1l\u00f3 t\u00f6r\u00f6lve: {user}",
    "Departments": "Oszt\u00e1lyok",
    "Description": "Le\u00edr\u00e1s",
    "Description is required": "Le\u00edr\u00e1s k\u00f6telez\u0151",
    "Desktop": "Desktop",
    "Details": "R\u00e9szletek",
    "Device": "Eszk\u00f6z",
    "Device Name": "Eszk\u00f6z neve",
    "Devices": "Eszk\u00f6z\u00f6k",
    "Direct Download Link:": "K\u00f6zvetlen let\u00f6lt\u00e9si link:",
    "Direct download link is copied to the clipboard.": "K\u00f6zvetlen let\u00f6lt\u00e9si link v\u00e1g\u00f3lapra m\u00e1solva",
    "Directory": "K\u00f6nyvt\u00e1r",
    "Disable Two-Factor Authentication": "K\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s kikapcsol\u00e1sa",
    "Document convertion failed.": "Dokumentum \u00e1talak\u00edt\u00e1sa meghi\u00fasult.",
    "Documents": "Dokumentumok",
    "Don't keep history": "Csak az utols\u00f3 v\u00e1ltozat megtart\u00e1sa",
    "Don't replace": "Ne cser\u00e9lje",
    "Download": "Let\u00f6lt\u00e9s",
    "Download an example file": "Mintaf\u00e1jl let\u00f6lt\u00e9se",
    "Download and upload": "Let\u00f6lt\u00e9s \u00e9s felt\u00f6lt\u00e9s",
    "Draft": "Piszkozat",
    "Drafts": "Piszkozatok",
    "Edit": "Szerkeszt\u00e9s",
    "Edit File": "F\u00e1jl szerkeszt\u00e9se",
    "Edit labels": "C\u00edmk\u00e9k szerkeszt\u00e9se",
    "Edit on cloud and download": "Szerkeszt\u00e9s a felh\u0151ben \u00e9s let\u00f6lt\u00e9s",
    "Edit succeeded": "Szerkeszt\u00e9s sikeres.",
    "Email": "E-mail",
    "Emails, separated by ','": "E-mail c\u00edmek \u201d,\u201d-vel elv\u00e1lasztva ",
    "Enable Two-Factor Authentication": "K\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s bekapcsol\u00e1sa",
    "Enable system admin to add Terms and Conditions, and all users will have to accept the terms.": "Enged\u00e9lyezi az Adminisztr\u00e1toroknak Felhaszn\u00e1l\u00e1si felt\u00e9telek l\u00e9trehoz\u00e1s\u00e1t, melyeket minden felhaszn\u00e1l\u00f3nak el kell fogadnia.",
    "Enable two factor authentication": "K\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s enged\u00e9lyez\u00e9se",
    "Enable users to share libraries to any groups in the system.": "Enged\u00e9lyezi a felhaszn\u00e1l\u00f3knak, k\u00f6tetek megoszt\u00e1s\u00e1t b\u00e1rmely csoporttal a rendszerben.",
    "Encrypt": "Titkos\u00edt\u00e1s",
    "Encrypted library": "Titkos\u00edtott k\u00f6tet",
    "Error": "Hiba",
    "Errors": "Hib\u00e1k",
    "Exit System Admin": "Admin kil\u00e9p\u00e9s",
    "Expiration": "Lej\u00e1rat",
    "Expiration Date:": "Lej\u00e1rati d\u00e1tum:",
    "Expiration days": "Lej\u00e1rati napok sz\u00e1ma",
    "Expiration time": "Lej\u00e1rat id\u0151pontja",
    "Expired": "Lej\u00e1rt",
    "Expired at": "Lej\u00e1rt",
    "Export Excel": "Export\u00e1l\u00e1s Excelbe",
    "Extensions of text files that can be online previewed, each suffix is separated by a comma.": "Sz\u00f6veg f\u00e1jl kiterjeszt\u00e9sek, melyek online megtek\u00edthet\u0151ek. Minden v\u00e9gz\u0151d\u00e9st ','-vel kell elv\u00e1lasztani.",
    "Failed": "Sikertelen",
    "Failed to copy %(name)s": "%(name)s m\u00e1sol\u00e1sa sikertelen",
    "Failed to delete draft %(draft)s.": "Piszkozat t\u00f6rl\u00e9se sikertelen %(draft)s.",
    "Failed to publish draft %(draft)s.": "Piszkozat publik\u00e1l\u00e1sa sikertelen %(draft)s.",
    "Failed. Please check the network.": "Sikertelen. Ellen\u0151rizze a h\u00e1l\u00f3zatot.",
    "Favorites": "Kedvencek",
    "File": "F\u00e1jl",
    "File Access": "F\u00e1jl hozz\u00e1f\u00e9r\u00e9s",
    "File Operations": "F\u00e1jlm\u0171veletek",
    "File Update": "F\u00e1jl friss\u00edt\u00e9s",
    "File Upload": "F\u00e1jl felt\u00f6lt\u00e9s",
    "File Uploading...": "F\u00e1jl felt\u00f6lt\u00e9s ...",
    "File does not exist.": "A f\u00e1jl nem l\u00e9tezik.",
    "File download is disabled: the share link traffic of owner is used up.": "F\u00e1jl let\u00f6lt\u00e9s letiltva: a megoszt\u00e1si link tulajdonosa el\u00e9rte a forgalmi korl\u00e1tot.",
    "Files": "F\u00e1jlok",
    "Folder": "K\u00f6nyvt\u00e1r",
    "Folder Permission": "K\u00f6nyvt\u00e1r jogosults\u00e1g",
    "Folder does not exist.": "A mappa nem l\u00e9tezik.",
    "Folders": "K\u00f6nyvt\u00e1rak",
    "Force user to change password when account is newly added or reset by admin": "K\u00e9nyszer\u00edti a felhaszn\u00e1l\u00f3t jelszav\u00e1nak megv\u00e1ltoztat\u00e1s\u00e1ra, \u00faj felhaszn\u00e1l\u00f3i fi\u00f3k l\u00e9trehoz\u00e1sakor, vagy ha egy Adminisztr\u00e1tor alaphelyzetbe \u00e1ll\u00edtja azt.",
    "Force user to use a strong password when sign up or change password.": "Megk\u00f6veteli a felhaszn\u00e1l\u00f3t\u00f3l er\u0151s jelsz\u00f3 haszn\u00e1lat\u00e1t regisztr\u00e1ci\u00f3 vagy jelsz\u00f3v\u00e1lt\u00e1s alkalm\u00e1val.",
    "Freeze user account when failed login attempts exceed limit.": "Felhaszn\u00e1l\u00f3i fi\u00f3k felf\u00fcggeszt\u00e9se, ha a sikertelen bejelentkez\u00e9si k\u00eds\u00e9rletek sz\u00e1ma el\u00e9rte a limitet.",
    "Generate": "Gener\u00e1l",
    "Global Address Book": "Glob\u00e1lis n\u00e9vjegyz\u00e9k",
    "Greater than or equal to {minDays_placeholder} days": "Legal\u00e1bb {minDays_placeholder} nap",
    "Grid": "R\u00e1cs",
    "Group": "Csoport",
    "Group Permission": "Csoport jogosults\u00e1g",
    "Group not found": "Csoport nem tal\u00e1lhat\u00f3",
    "Groups": "Csoportok",
    "Guest": "Vend\u00e9g",
    "Handled": "Kezelve",
    "Help": "Seg\u00edts\u00e9g",
    "Hide": "Elrejt",
    "History": "Napl\u00f3",
    "History Setting": "Napl\u00f3be\u00e1ll\u00edt\u00e1sok",
    "History Versions": "Kor\u00e1bbi verzi\u00f3k",
    "IP": "IP",
    "If turn on, the desktop clients will not be able to sync a folder outside the default Seafile folder.": "Ha bekapcsolva, az asztali kliensalkalmaz\u00e1sok nem tudnak az alap\u00e9rtelmezett Seafile mapp\u00e1n k\u00edv\u00fcli mapp\u00e1t szinkroniz\u00e1lni.",
    "If you don't have any device with you, you can access your account using backup codes.": "Amennyiben nincs \u00f6nn\u00e9l az azonos\u00edt\u00f3 eszk\u00f6z, haszn\u00e1lhatja a tartal\u00e9k k\u00f3dokat fi\u00f3kja el\u00e9r\u00e9s\u00e9hez.",
    "Image": "K\u00e9p",
    "Images": "K\u00e9pek",
    "Import Members": "Tagok import\u00e1l\u00e1sa",
    "Import users": "Felhaszn\u00e1l\u00f3k import\u00e1l\u00e1sa",
    "Import users from a .xlsx file": "Felhaszn\u00e1l\u00f3k import\u00e1l\u00e1sa .xlsx f\u00e1jlb\u00f3l",
    "In all libraries": "Minden k\u00f6tetben",
    "Inactive": "Nem akt\u00edv",
    "Info": "Inf\u00f3.",
    "Input file extensions here, separate with ','": "F\u00e1jlkiterjeszt\u00e9sek list\u00e1ja ','-vel elv\u00e1lasztva",
    "Institution": "Int\u00e9zm\u00e9ny",
    "Institutions": "Int\u00e9zm\u00e9nyek",
    "Internal Link": "Bels\u0151 link",
    "Internal Server Error": "Bels\u0151 kiszolg\u00e1l\u00f3hiba",
    "Internal link has been copied to clipboard": "Bels\u0151 link a v\u00e1g\u00f3lapra m\u00e1solva",
    "Invalid destination path": "\u00c9rv\u00e9nytelen c\u00e9l \u00fatvonal",
    "Invalid month, should be yyyymm.": "\u00c9rv\u00e9nytelen h\u00f3nap, helyes form\u00e1tum: \u00e9\u00e9\u00e9\u00e9-hh",
    "Invitations": "Megh\u00edv\u00e1sok",
    "Invite Time": "Megh\u00edv\u00e1s ideje",
    "Invited at": "Megh\u00edv\u00e1s ideje",
    "Inviter": "Megh\u00edv\u00f3",
    "It is required.": "Sz\u00fcks\u00e9ges.",
    "Keep full history": "\u00d6sszes v\u00e1ltozat megtart\u00e1sa",
    "LDAP": "LDAP",
    "LDAP(imported)": "LDAP(bet\u00f6ltve)",
    "Label": "C\u00edmke",
    "Labels": "C\u00edmk\u00e9k",
    "Language": "Nyelv",
    "Language Setting": "Nyelvi be\u00e1ll\u00edt\u00e1sok",
    "Last Access": "Utols\u00f3 el\u00e9r\u00e9s",
    "Last Login": "Utols\u00f3 bel\u00e9p\u00e9s",
    "Last Update": "Utols\u00f3 friss\u00edt\u00e9s ",
    "Last modified by": "Utolj\u00e1ra m\u00f3dos\u00edt\u00f3",
    "Leave Share": "Megoszt\u00e1s elhagy\u00e1sa",
    "Less than or equal to {maxDays_placeholder} days": "Maximum {maxDays_placeholder} nap",
    "Libraries": "K\u00f6tetek",
    "Library": "K\u00f6tet",
    "Library Type": "K\u00f6tet t\u00edpusa",
    "Limits": "Hat\u00e1rok",
    "Link": "Link",
    "Linked Devices": "Kapcsolt eszk\u00f6z\u00f6k",
    "Links": "Linkek",
    "List": "Lista",
    "List your account in global address book, so that others can find you by typing your name.": "Felhaszn\u00e1l\u00f3i fi\u00f3kja list\u00e1z\u00e1sa a glob\u00e1lis n\u00e9vjegyz\u00e9kben, \u00edgy m\u00e1sik megtal\u00e1lhatj\u00e1k \u00d6nt a nev\u00e9nek b\u00edr\u00e1s\u00e1val.",
    "Local draft": "Helyi piszkozat",
    "Local draft saved": "Helyi piszkozat elmentve",
    "Location": "Helysz\u00edn",
    "Lock": "Lez\u00e1r",
    "Log out": "Kijelentkez\u00e9s",
    "Login Background Image": "Bejelentkez\u0151 k\u00e9perny\u0151 h\u00e1tt\u00e9rk\u00e9p",
    "Logs": "Napl\u00f3k",
    "Manage Members": "Tagok kezel\u00e9se",
    "Manage group members": "Csoporttagok kezel\u00e9se",
    "Mark all read": "Mindet olvasottnak jel\u00f6l",
    "Member": "Tag",
    "Members": "Tagok",
    "Message": "\u00dczenet",
    "Message (optional):": "\u00dczenet (opcion\u00e1lis):",
    "Mobile": "Mobil",
    "Modification Details": "M\u00f3dos\u00edt\u00e1s r\u00e9szletei",
    "Modified": "M\u00f3dos\u00edtva",
    "Modified files": "M\u00f3dos\u00edtott f\u00e1jlok",
    "Modifier": "M\u00f3dos\u00edt\u00f3:",
    "Month:": "H\u00f3nap:",
    "Monthly User Traffic": "Havi felhaszn\u00e1l\u00f3i forgalom",
    "More": "Tov\u00e1bb",
    "More Operations": "Tov\u00e1bbi m\u0171veletek",
    "Move": "\u00c1thelyez\u00e9s",
    "Move selected item(s) to:": "Kiv\u00e1lasztott elem(ek) mozgat\u00e1sa ide: ",
    "Moved file": "\u00c1thelyezett f\u00e1jl",
    "Moved folder": "\u00c1thelyezett mappa",
    "My Groups": "Saj\u00e1t csoportok",
    "My Libraries": "K\u00f6teteim",
    "Name": "N\u00e9v",
    "Name is required": "N\u00e9v sz\u00fcks\u00e9ges",
    "Name is required.": "N\u00e9v k\u00f6telez\u0151.",
    "Name should not include '/'.": "N\u00e9v nem tartalmazhat \"/\" jelet.",
    "Name(optional)": "N\u00e9v (opcion\u00e1lis)",
    "Network error": "H\u00e1l\u00f3zati hiba",
    "New": "\u00daj",
    "New Department": "\u00daj oszt\u00e1ly",
    "New Department Library": "\u00daj oszt\u00e1lyk\u00f6tet",
    "New Draft": "\u00daj piszkozat",
    "New Excel File": "\u00daj Excel f\u00e1jl",
    "New File": "\u00daj f\u00e1jl",
    "New Folder": "\u00daj k\u00f6nyvt\u00e1r",
    "New Group": "\u00daj csoport",
    "New Library": "\u00daj k\u00f6tet",
    "New Markdown File": "\u00daj Markdown f\u00e1jl",
    "New Password": "\u00daj jelsz\u00f3",
    "New Password Again": "\u00daj jelsz\u00f3 ism\u00e9t",
    "New PowerPoint File": "\u00daj PowerPoint f\u00e1jl",
    "New Sub-department": "\u00daj aloszt\u00e1ly",
    "New Tag": "\u00daj c\u00edmke",
    "New Wiki": "\u00daj Wiki",
    "New Word File": "\u00daj Word f\u00e1jl",
    "New directories": "\u00daj k\u00f6nyvt\u00e1rak",
    "New file name": "\u00daj f\u00e1jl neve",
    "New files": "\u00daj f\u00e1jlok",
    "New password is too short": "Az \u00faj jelsz\u00f3 r\u00f6vid",
    "New passwords don't match": "Az \u00faj jelszavak nem egyeznek",
    "Next": "K\u00f6vetkez\u0151",
    "No": "Nem",
    "No connected devices": "Nincsenek csatlakozott eszk\u00f6z\u00f6k",
    "No departments": "Nincsenek oszt\u00e1lyok",
    "No draft yet": "Nincsenek piszkozatok",
    "No groups": "Nincs csoport",
    "No libraries": "Nincs k\u00f6tet",
    "No libraries have been shared with you": "Nincsen egyetlen k\u00f6nyvt\u00e1r sem megosztva \u00d6nnel",
    "No members": "Nincs tag",
    "No public libraries": "Nincs nyilv\u00e1nos k\u00f6nyvt\u00e1r",
    "No result": "Nincs tal\u00e1lat",
    "No sub-departments": "Nincsenek aloszt\u00e1lyok",
    "No sync errors": "Nincs szinkroniz\u00e1l\u00e1si hiba",
    "None": "Nincs",
    "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.": "Megjegyz\u00e9s: a webes fel\u00fcleten megadott be\u00e1ll\u00edt\u00e1sok az adatb\u00e1zisban r\u00f6gz\u00fclnek (seahub-db/constance_config). Ezeknek magasabb a priorit\u00e1suk a config f\u00e1jlban r\u00f6gz\u00edtettekn\u00e9l.",
    "Notification": "\u00c9rtes\u00edt\u00e9s",
    "Notification Detail": "\u00c9rtes\u00edt\u00e9s r\u00e9szletei",
    "Notifications": "\u00c9rtes\u00edt\u00e9sek",
    "Number of days that keep user sign in.": "Napok sz\u00e1ma, am\u00edg a felhaszn\u00e1l\u00f3 bejelentkezve marad.",
    "Number of groups": "Csoportok sz\u00e1ma",
    "Off": "Ki",
    "Old Password": "R\u00e9gi jelsz\u00f3",
    "On": "Be",
    "Online Preview": "Online el\u0151n\u00e9zet",
    "Online view is not applicable to this file format": "Az online el\u0151n\u00e9zet nem lehets\u00e9ges enn\u00e9l a f\u00e1jlform\u00e1tumn\u00e1l",
    "Only Show": "Csak megjelen\u00edt\u00e9s",
    "Only keep a period of history:": "Csak egy id\u0151szak megtart\u00e1sa:",
    "Open parent folder": "Sz\u00fcl\u0151k\u00f6nyvt\u00e1r megnyit\u00e1sa",
    "Open via Client": "Megnyit\u00e1s kliensben",
    "Operation": "M\u0171velet",
    "Operation succeeded.": "A m\u0171velet befejez\u0151d\u00f6tt.",
    "Operations": "M\u0171veletek",
    "Organization": "Szervezet",
    "Organization Admin": "Szervezeti adminisztr\u00e1tor",
    "Organizations": "Szervezetek",
    "Other Libraries": "M\u00e1s k\u00f6tetek",
    "Out of quota.": "Kv\u00f3ta t\u00fall\u00e9p\u00e9s.",
    "Owned Libraries": "Birtokolt k\u00f6tetek",
    "Owner": "Tulajdonos",
    "Owner can use admin panel in an organization, must be a new account.": "A tulajdonos a szervezet be\u00e1ll\u00edt\u00e1sait kezelheti, \u00faj fi\u00f3knak kell lennie.",
    "Packaging...": "Csomagol\u00e1s",
    "Password": "Jelsz\u00f3",
    "Password again": "Jelsz\u00f3 ism\u00e9t",
    "Password is too short": "A jelsz\u00f3 t\u00fal r\u00f6vid",
    "Password:": "Jelsz\u00f3:",
    "Passwords don't match": "Nem egyeznek a megadott jelszavak.",
    "Path": "El\u00e9r\u00e9si \u00fat",
    "Permission": "Jogosults\u00e1g",
    "Permission denied": "Jogosults\u00e1g megtagadva",
    "Permission:": "Jogosults\u00e1g:",
    "Platform": "Platform",
    "Please check the network.": "Ellen\u0151rizze a h\u00e1l\u00f3zatot.",
    "Please choose a .xlsx file.": "V\u00e1lasszon egy .xlsx f\u00e1jlt",
    "Please enter 1 or more character": "K\u00e9rem adjon meg m\u00e9g 1 vagy t\u00f6bb karaktert",
    "Please enter a new password": "K\u00e9rem adja meg az \u00faj jelsz\u00f3t",
    "Please enter a non-negative integer": "Nem negat\u00edv eg\u00e9sz sz\u00e1mot adjon meg",
    "Please enter days": "Adja meg a napok sz\u00e1m\u00e1t",
    "Please enter password": "K\u00e9rem adja meg a jelsz\u00f3t",
    "Please enter the new password again": "K\u00e9rem adja meg \u00fajra az \u00faj jelsz\u00f3t",
    "Please enter the old password": "K\u00e9rem adja meg a r\u00e9gi jelsz\u00f3t",
    "Please enter the password again": "K\u00e9rem adja meg a jelsz\u00f3t \u00fajra",
    "Please input at least an email.": "Adjon meg legal\u00e1bb egy e-mail c\u00edmet",
    "Please select a library to share.": "V\u00e1lasszon k\u00f6tetet a megoszt\u00e1shoz",
    "Preview and download": "El\u0151n\u00e9zet \u00e9s let\u00f6lt\u00e9s",
    "Preview only": "Csak el\u0151n\u00e9zet",
    "Previous": "El\u0151z\u0151",
    "Professional Edition": "Professzion\u00e1lis verzi\u00f3",
    "Profile": "Profil",
    "Profile Setting": "Profilbe\u00e1ll\u00edt\u00e1sok",
    "Publish": "Publik\u00e1l\u00e1s",
    "Publish draft": "Piszkozat publik\u00e1l\u00e1sa",
    "Quota": "Kv\u00f3ta",
    "Quota is invalid.": "\u00c9rv\u00e9nytelen kv\u00f3ta",
    "Read-Only": "Csak olvahat\u00f3",
    "Read-Only folder": "Csak olvashat\u00f3 mappa",
    "Read-Only library": "Csak olvashat\u00f3 k\u00f6tet",
    "Read-Write": "\u00cdr\u00e1s-olvas\u00e1s",
    "Read-Write folder": "\u00cdrhat\u00f3-olvashat\u00f3 mappa",
    "Read-Write library": "\u00cdrhat\u00f3-olvashat\u00f3 k\u00f6tet",
    "Really want to delete your account?": "Biztosan t\u00f6rli a fi\u00f3kot?",
    "Refresh": "Friss\u00edt\u00e9s",
    "Remove": "Elt\u00e1vol\u00edt\u00e1s",
    "Removed all items from trash.": "Az \u00f6sszes elem elt\u00e1vol\u00edtva a kuk\u00e1b\u00f3l.",
    "Removed items older than {n} days from trash.": "{n} napn\u00e1l r\u00e9gebbi elemek elt\u00e1vol\u00edtva a kuk\u00e1b\u00f3l.",
    "Rename": "\u00c1tnevez\u00e9s",
    "Rename File": "F\u00e1jl \u00e1tnevez\u00e9se",
    "Rename Folder": "K\u00f6nyvt\u00e1r \u00e1tnevez\u00e9se",
    "Rename group to": "Csoport \u00e1tnevez\u00e9se a k\u00f6vetkez\u0151re:",
    "Renamed file": "\u00c1tnevezett f\u00e1jl",
    "Renamed folder": "\u00c1tnevezett mappa",
    "Renamed library": "\u00c1tnevezett k\u00f6tet",
    "Renamed or Moved files": "\u00c1tnevezett/\u00e1thelyezett f\u00e1jlok",
    "Replace": "Csere",
    "Replace file {filename}?": "Fel\u00fcl\u00edrja: {filename}?",
    "Replacing it will overwrite its content.": "A cser\u00e9je a tartalom fel\u00fcl\u00edr\u00e1s\u00e1val j\u00e1r.",
    "Reports": "Jelent\u00e9sek",
    "Reset Password": "Jelsz\u00f3 \u00e1t\u00e1ll\u00edt\u00e1sa",
    "ResetPwd": "\u00daj jelsz\u00f3",
    "Restore": "Vissza\u00e1ll\u00edt\u00e1s",
    "Restore Library": "K\u00f6tet vissza\u00e1ll\u00edt\u00e1sa",
    "Restored file": "Vissza\u00e1ll\u00edtott f\u00e1jl",
    "Restored folder": "Vissza\u00e1ll\u00edtott mappa",
    "Restored library": "Vissza\u00e1ll\u00edtott k\u00f6tet",
    "Result": "Tal\u00e1lat",
    "Revoke Admin": "Admin jog elv\u00e9tele",
    "Role": "Szerep",
    "Save": "Ment\u00e9s",
    "Save as ...": "Ment\u00e9s m\u00e1sk\u00e9nt...",
    "Save to:": "Ment\u00e9s ide:",
    "Saving...": "Ment\u00e9s...",
    "Seafile": "Seafile",
    "Search": "Keres",
    "Search files in this library": "F\u00e1jlok keres\u00e9se ebben a k\u00f6tetben",
    "Search groups": "Csoportok keres\u00e9se",
    "Select File": "F\u00e1jl kiv\u00e1laszt\u00e1sa",
    "Select Tags": "C\u00edmk\u00e9k kiv\u00e1laszt\u00e1sa",
    "Select a group": "Csoport kiv\u00e1laszt\u00e1sa",
    "Select groups": "Csoportok kiv\u00e1laszt\u00e1sa",
    "Select libraries to share": "V\u00e1lasszon k\u00f6teteket a megoszt\u00e1shoz",
    "Send": "K\u00fcld\u00e9s",
    "Send activation Email after user registration.": "Aktiv\u00e1l\u00f3 E-mail k\u00fcld\u00e9se regisztr\u00e1ci\u00f3 ut\u00e1n.",
    "Send to:": "C\u00edmzett:",
    "Sending...": "K\u00fcld\u00e9s...",
    "Server Version: ": "Kiszolg\u00e1l\u00f3verzi\u00f3: ",
    "Set Admin": "Admin jog megad\u00e1sa",
    "Set Password": "Jelsz\u00f3 be\u00e1ll\u00edt\u00e1sa",
    "Set Quota": "Kv\u00f3ta be\u00e1ll\u00edt\u00e1sa",
    "Set permission": "Jogosults\u00e1g be\u00e1ll\u00edt\u00e1sa",
    "Set to current": "Be\u00e1ll\u00edt\u00e1s aktu\u00e1lisnak",
    "Set user contact email": "Kapcsolat E-mail be\u00e1ll\u00edt\u00e1sa",
    "Set user name": "Felhaszn\u00e1l\u00f3n\u00e9v be\u00e1ll\u00edt\u00e1sa",
    "Set {placeholder}'s permission": "{placeholder} jogosults\u00e1g be\u00e1ll\u00edt\u00e1sa",
    "Settings": "Be\u00e1ll\u00edt\u00e1sok",
    "Share": "Megoszt\u00e1s",
    "Share Admin": "Megoszt\u00e1sok kezel\u00e9se",
    "Share From": "Megoszt\u00e1s innen",
    "Share Link": "Megoszt\u00e1s link",
    "Share Link Traffic": "Megoszt\u00e1si link forgalom",
    "Share Links": "Megoszt\u00e1si linkek",
    "Share To": "C\u00edmzett",
    "Share existing libraries": "Megl\u00e9v\u0151 k\u00f6tetek megoszt\u00e1sa",
    "Share link download": "Megoszt\u00e1si link let\u00f6lt\u00e9s",
    "Share link is copied to the clipboard.": "Megoszt\u00e1si link v\u00e1g\u00f3lapra m\u00e1solva.",
    "Share link upload": "Megoszt\u00e1si link felt\u00f6lt\u00e9s",
    "Share to group": "Megoszt\u00e1s csoporttal",
    "Share to user": "Megoszt\u00e1s felhaszn\u00e1l\u00f3val",
    "Shared By": "Megoszt\u00f3:",
    "Shared Libraries": "Megosztott k\u00f6tetek",
    "Shared Links": "Megoszt\u00e1s linkek",
    "Shared by:": "Megoszt\u00f3:",
    "Shared by: ": "Megoszt\u00f3: ",
    "Shared with all": "Mindenkivel megosztva",
    "Shared with groups": "Csoporttal megosztva",
    "Shared with me": "Velem megosztva",
    "Show": "Mutat",
    "Show Codes": "K\u00f3dok mutat\u00e1sa",
    "Side Nav Menu": "Oldals\u00e1vi men\u00fc",
    "Site name used in email sending": "E-mailben megjelen\u0151 oldal neve",
    "Site title shown in a browser tab": "Oldal c\u00edme a b\u00f6ng\u00e9sz\u0151 f\u00fcl\u00f6n",
    "Size": "M\u00e9ret",
    "Space Used": "Felhaszn\u00e1lt ter\u00fclet",
    "Space Used / Quota": "T\u00e1r haszn\u00e1lva / Kv\u00f3ta",
    "Star": "Csillagoz\u00e1s",
    "Statistic": "Statisztik\u00e1k",
    "Status": "\u00c1llapot",
    "Storage": "T\u00e1rhely",
    "Storage Used": "Felhaszn\u00e1lt t\u00e1rhely",
    "Sub-departments": "Aloszt\u00e1lyok",
    "Submit": "Bek\u00fcld\u00e9s",
    "Success": "Sikeres",
    "Successfully added label(s) for library {placeholder}": "C\u00edmk\u00e9k hozz\u00e1adva a(z) {placeholder} k\u00f6tethez.",
    "Successfully changed library password.": "K\u00f6tetjelsz\u00f3 megv\u00e1ltoztat\u00e1sa sikeres",
    "Successfully copied %(name)s and %(amount)s other items.": "%(name)s m\u00e1sol\u00e1sa \u00e9s m\u00e9g %(amount)s m\u00e1sik elem\u00e9 sikeres.",
    "Successfully copied %(name)s and 1 other item.": "%(name)s m\u00e1sol\u00e1sa \u00e9s m\u00e9g 1 m\u00e1sik elem\u00e9 sikeres.",
    "Successfully copied %(name)s.": "%(name)s m\u00e1sol\u00e1sa sikeres.",
    "Successfully deleted 1 item": "1 elem sikeresen t\u00f6r\u00f6lve.",
    "Successfully deleted 1 item.": "1 elem sikeresen t\u00f6r\u00f6lve.",
    "Successfully deleted draft %(draft)s.": "Piszkozat t\u00f6r\u00f6lve %(draft)s.",
    "Successfully deleted {name}": "Sikeresen t\u00f6r\u00f6lve {name}",
    "Successfully edited labels.": "C\u00edmk\u00e9k szerkeszt\u00e9se sikeres",
    "Successfully invited %(email) and %(num) other people.": "%(email) \u00e9s tov\u00e1bbi %(num) ember megh\u00edvva.",
    "Successfully invited %(email).": "%(email) sikeresen megh\u00edvva",
    "Successfully moved %(name)s and %(amount)s other items.": "%(name)s \u00e1thelyez\u00e9se \u00e9s m\u00e9g %(amount)s m\u00e1sik elem\u00e9 sikeres.",
    "Successfully moved %(name)s and 1 other item.": "%(name)s \u00e1thelyez\u00e9se \u00e9s m\u00e9g 1 m\u00e1sik elem\u00e9 sikeres.",
    "Successfully moved %(name)s.": "%(name)s sikeresen \u00e1tmozgatva.",
    "Successfully published draft %(draft)s.": "Piszkozat publik\u00e1lva %(draft)s.",
    "Successfully reset password to %(passwd)s for user %(user)s.": "%(user)s jelszava sikeresen \u00e1t\u00e1ll\u00edtva erre: %(passwd)s.",
    "Successfully restored 1 item.": "1 elem sikeresen vissza\u00e1ll\u00edtva.",
    "Successfully restored the library.": "K\u00f6nyvt\u00e1r sikeresen vissza\u00e1ll\u00edtva.",
    "Successfully revoke the admin permission of %s": "%s felhaszn\u00e1l\u00f3t\u00f3l az adminisztr\u00e1tori jogok megvon\u00e1sa sikeres",
    "Successfully saved": "Sikeresen elmentve",
    "Successfully sent to {placeholder}": "Sikeresen elk\u00fcldve ide: {placeholder}",
    "Successfully set %s as admin.": "%s adminisztr\u00e1tornak val\u00f3 be\u00e1ll\u00edt\u00e1sa sikeres.",
    "Successfully set library history.": "K\u00f6tetnapl\u00f3 be\u00e1ll\u00edt\u00e1sa sikeres",
    "Successfully transferred the group.": "Csoport sikeresen \u00e1tadva.",
    "Successfully transferred the library.": "K\u00f6tet \u00e1tad\u00e1sa sikeres.",
    "Successfully unshared library {placeholder}": "{placeholder} megoszt\u00e1sa sikeresen megsz\u00fcntetve",
    "Suggestion": "Javaslatok",
    "Sync": "Szinkroniz\u00e1l\u00e1s",
    "Sync Download": "Szinkroniz\u00e1ci\u00f3 let\u00f6l\u00e9s",
    "Sync Traffic": "Szinkroniz\u00e1ci\u00f3 forgalom",
    "Sync Upload": "Szinkroniz\u00e1ci\u00f3 felt\u00f6lt\u00e9s",
    "System": "Rendszer",
    "System Admin": "Rendszer-adminisztr\u00e1tor",
    "System Info": "Rendszer inform\u00e1ci\u00f3",
    "Tags": "Tagek",
    "Template": "Sablon",
    "Terms": "Felt\u00e9telek",
    "Terms and Conditions": "Felhaszn\u00e1l\u00e1si felt\u00e9telek",
    "Text": "Sz\u00f6veg",
    "Text files": "Sz\u00f6veg f\u00e1jlok",
    "The URL of the server, like https://seafile.example.com or http://192.168.1.2:8000": "Szerver c\u00edme, pl: https://seafile.example.com vagy http://192.168.1.2:8000",
    "The internal URL for downloading/uploading files. Users will not be able to download/upload files if this is not set correctly. If you config Seafile behind Nginx/Apache, it should be SERVICE_URL/seafhttp, like https://seafile.example.com/seafhttp .": "A bels\u0151 URL a f\u00e1jlok le/felt\u00f6lt\u00e9s\u00e9hez. Hib\u00e1s be\u00e1ll\u00edt\u00e1s eset\u00e9n a felhaszn\u00e1l\u00f3k nem lesznek k\u00e9pesek le/felt\u00f6lteni f\u00e1jlokat. Amennyiben Nginx/Apache m\u00f6g\u00f6tt fut a Seafile szerver, SERVICE_URL/seafhttp-nek kell lennie, pl.: https://seafile.example.com/seafhttp.",
    "The least number of characters an account password should include.": "Felhaszn\u00e1l\u00f3 jelszav\u00e1nak minim\u00e1lis hossza.",
    "The least number of characters an encrypted library password should include.": "Titkos\u00edtott k\u00f6tet jelszav\u00e1nak minim\u00e1lis hossza.",
    "The level(1-4) of an account password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "Felhaszn\u00e1l\u00f3 jelszav\u00e1nak er\u0151ss\u00e9ge (1-4). P\u00e9ld\u00e1ul a '3' azt jelenti, hogy a jelsz\u00f3nak legal\u00e1bb h\u00e1rom t\u00edpust kell tartalmaznia a k\u00f6vetkez\u0151kb\u0151l: sz\u00e1m, nagybet\u0171, kisbet\u0171, \u00e9s egy\u00e9b karakterek.",
    "The maximum number of failed login attempts before showing CAPTCHA.": "Maxim\u00e1lis sikertelen bejelentkez\u00e9si k\u00eds\u00e9rletek a CAPTCHA megjelen\u00edt\u00e9se el\u0151tt.",
    "The name \"{name}\" is already taken. Please choose a different name.": "A n\u00e9v \"{name}\" haszn\u00e1latban van. K\u00e9rem, v\u00e1lasszon egy m\u00e1sikat.",
    "The owner of this library has run out of space.": "A k\u00f6tet tulajdonos\u00e1nak elfogyott a t\u00e1rhelye.",
    "The password is too short.": "A jelsz\u00f3 t\u00fal r\u00f6vid.",
    "The password will be kept in the server for only 1 hour.": "A jelsz\u00f3 egy \u00f3r\u00e1n \u00e1t lesz t\u00e1rolva a kiszolg\u00e1l\u00f3n.",
    "This file has been updated.": "Ez a f\u00e1jl friss\u00edtve lett.",
    "This file is in draft stage.": "Ez a f\u00e1jl piszkozat \u00e1llapotban van.",
    "This is a special group representing a department.": "Ez a speci\u00e1lis csoport egy oszt\u00e1lyt reprezent\u00e1l.",
    "This library is password protected": "Ez a k\u00f6tet jelsz\u00f3val van v\u00e9dve",
    "This operation will not be reverted. Please think twice!": "Ezt a m\u0171veletet nem lehet visszavonni. K\u00e9rem gondolja meg!",
    "Time": "Id\u0151",
    "Tip: -2 means no limit.": "Tipp: A -2 azt jelenti, hogy nincs korl\u00e1t.",
    "Tip: 0 means default limit": "Tipp: a 0 az alap\u00e9rtelmezett korl\u00e1tot jelenti",
    "Tip: a snapshot will be generated after modification, which records the library state after the modification.": "Tipp: Minden m\u00f3dos\u00edt\u00e1skor egy pillanatk\u00e9p k\u00e9sz\u00fcl, \u00edgy vissza\u00e1ll\u00edthat\u00f3 a k\u00f6tet el\u0151z\u0151 \u00e1llapota.",
    "Tip: you can search by keyword in name.": "Tipp: kulcssz\u00f3ra is lehet keresni a n\u00e9vben.",
    "Token": "Token",
    "Tools": "Eszk\u00f6z\u00f6k",
    "Total Devices": "\u00d6sszes eszk\u00f6z",
    "Total Storage": "\u00d6sszes t\u00e1rhely",
    "Total Traffic": "\u00d6sszes forgalom",
    "Total Users": "\u00d6sszes felhaszn\u00e1l\u00f3",
    "Traffic": "Forgalom",
    "Transfer": "\u00c1tad",
    "Transfer Group": "Csoport \u00e1tad\u00e1sa",
    "Transfer Library": "K\u00f6tet \u00e1tad\u00e1sa",
    "Transferred group {group_name} from {user_from} to {user_to}": "{group_name} csoport \u00faj tulajdonosa {user_to}. R\u00e9gi tulajdonos: {user_from}",
    "Transferred library {library_name} from {user_from} to {user_to}": "{group_name} k\u00f6tet \u00faj tulajdonosa {user_to}. R\u00e9gi tulajdonos: {user_from}",
    "Trash": "Kuka",
    "Two-Factor Authentication": "K\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s",
    "Two-factor authentication is not enabled for your account. Enable two-factor authentication for enhanced account security.": "A felhaszn\u00e1l\u00f3i fi\u00f3kon a k\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s nem akt\u00edv. Kapcsolja be a fokozott biztons\u00e1g\u00e9rt.",
    "Type": "T\u00edpus",
    "Unknown": "Ismeretlen",
    "Unlink": "Lev\u00e1laszt\u00e1s",
    "Unlink device": "Eszk\u00f6z sz\u00e9tkapcsol\u00e1sa",
    "Unlock": "Kinyit",
    "Unshare": "Megoszt\u00e1s t\u00f6rl\u00e9se",
    "Unshare Library": "K\u00f6nyvt\u00e1r megoszt\u00e1s\u00e1nak visszavon\u00e1sa",
    "Unstar": "Nem kedvenc",
    "Update": "Friss\u00edt\u00e9s",
    "Update Terms and Conditions": "Felhaszn\u00e1l\u00e1si felt\u00e9telek friss\u00edt\u00e9se",
    "Updated draft": "M\u00f3dos\u00edtott piszkozat",
    "Updated file": "Friss\u00edtett f\u00e1jl",
    "Upgrade to Pro Edition": "Friss\u00edt\u00e9s professzion\u00e1lis verzi\u00f3ra",
    "Upload": "Felt\u00f6lt\u00e9s",
    "Upload Files": "F\u00e1jlok felt\u00f6lt\u00e9se",
    "Upload Folder": "K\u00f6nyvt\u00e1r felt\u00f6lt\u00e9se",
    "Upload Link": "Felt\u00f6lt\u00e9si hivatkoz\u00e1s",
    "Upload Link:": "Felt\u00f6t\u00e9si link:",
    "Upload Links": "Felt\u00f6lt\u00e9si linkek",
    "Upload file": "F\u00e1jl felt\u00f6lt\u00e9se",
    "Use custom CSS": "Egy\u00e9ni CSS haszn\u00e1lata",
    "Use draft": "Piszkozat haszn\u00e1lata",
    "Used:": "Foglalt:",
    "User": "Felhaszn\u00e1l\u00f3",
    "User Permission": "Felhaszn\u00e1l\u00f3i jogosults\u00e1g",
    "User Storage": "Felhaszn\u00e1l\u00f3i t\u00e1rhely",
    "User not found": "Felhaszn\u00e1l\u00f3 nem tal\u00e1lhat\u00f3",
    "Username:": "Felhaszn\u00e1l\u00f3n\u00e9v:",
    "Users": "Felhaszn\u00e1l\u00f3k",
    "Verify": "Meger\u0151s\u00edt",
    "Version": "Verzi\u00f3",
    "Version Number": "Verzi\u00f3sz\u00e1m",
    "Video": "Vide\u00f3",
    "View": "Megtekint\u00e9s",
    "View Draft": "Piszkozat megjelen\u00edt\u00e9se",
    "View Snapshot": "Pillanatk\u00e9p megtekint\u00e9se",
    "View profile and more": "Profil megtekint\u00e9se",
    "Virus File": "V\u00edrus f\u00e1jl",
    "Virus Scan": "V\u00edruskeres\u0151",
    "Visited": "Megtekintve",
    "Visits": "L\u00e1togat\u00e1sok ",
    "Web Download": "Web let\u00f6lt\u00e9s",
    "Web Traffic": "Web forgalom",
    "Web Upload": "Web felt\u00f6lt\u00e9s",
    "Wrong password": "Hib\u00e1s jelsz\u00f3",
    "Yes": "Igen",
    "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "Vend\u00e9g felhaszn\u00e1l\u00f3t is hozz\u00e1adhat, aki nem tud k\u00f6tetet \u00e9s csoportot l\u00e9trehozni.",
    "You can create libraries by clicking the \"New Library\" button above.": "K\u00f6teteket a fenti \"\u00daj K\u00f6tet\" gombra kattintva hozhat l\u00e9tre.",
    "You can use this field at login.": "Ezt a mez\u0151t haszn\u00e1lhatja a bejelentkez\u00e9shez.",
    "You don't have any upload links": "\u00d6nnek nincsenek felt\u00f6lt\u00e9si linkjei",
    "You have an unsaved draft. Do you like to use it?": "Egy el nem mentett piszkozatot is l\u00e9tezik. Szeretn\u00e9 azt haszn\u00e1lni?",
    "You have not shared any folders": "Nem osztott meg egyetlen k\u00f6nyvt\u00e1rat sem",
    "Your notifications will be sent to this email.": "Az \u00e9rtes\u00edt\u0151 erre az email c\u00edmre lesz elk\u00fcldve.",
    "ZIP": "ZIP",
    "activate after registration": "Aktiv\u00e1l\u00e1s regisztr\u00e1ci\u00f3 ut\u00e1n",
    "all": "\u00f6sszes",
    "all members": "minden tag",
    "allow new registrations": "Regisztr\u00e1ci\u00f3 enged\u00e9lyez\u00e9se",
    "days": "nap",
    "deleted": "t\u00f6r\u00f6lve",
    "icon": "ikon",
    "keep sign in": "Bejelentkezve maradok",
    "library password minimum length": "K\u00f6tetjelsz\u00f3 minim\u00e1lis hossza",
    "locked": "lez\u00e1rva",
    "name": "n\u00e9v",
    "password minimum length": "Jelsz\u00f3 minim\u00e1lis hossza",
    "password strength level": "Jelsz\u00f3 er\u0151ss\u00e9ge",
    "send activation email": "Aktiv\u00e1l\u00f3 E-mail k\u00fcld\u00e9se",
    "shared by:": "megoszt\u00f3:",
    "show more": "t\u00f6bb mutat\u00e1sa",
    "starred": "kedvenc",
    "state": "\u00e1llapot",
    "successfully added user %s.": "%s hozz\u00e1ad\u00e1sa sikeres.",
    "text file extensions": "Sz\u00f6vegf\u00e1jl kiterjeszt\u00e9sek",
    "to": "ide:",
    "unstarred": "nem kedvenc",
    "you can also press \u2190 ": "A \u2190 gombot is haszn\u00e1lhatja",
    "you can also press \u2192": "a \u2192 gombot is haszn\u00e1lhatja ",
    "{file} and {n} other files": "{file} \u00e9s {n} egy\u00e9b f\u00e1jl",
    "{number_placeholder} / Page": "{number_placeholder} / Oldal",
    "{placeholder} Folder Permission": "{placeholder} k\u00f6nyvt\u00e1r jogosults\u00e1ga"
  };
  for (const key in newcatalog) {
    django.catalog[key] = newcatalog[key];
  }
  

  if (!django.jsi18n_initialized) {
    django.gettext = function(msgid) {
      const value = django.catalog[msgid];
      if (typeof value === 'undefined') {
        return msgid;
      } else {
        return (typeof value === 'string') ? value : value[0];
      }
    };

    django.ngettext = function(singular, plural, count) {
      const value = django.catalog[singular];
      if (typeof value === 'undefined') {
        return (count == 1) ? singular : plural;
      } else {
        return value.constructor === Array ? value[django.pluralidx(count)] : value;
      }
    };

    django.gettext_noop = function(msgid) { return msgid; };

    django.pgettext = function(context, msgid) {
      let value = django.gettext(context + '\x04' + msgid);
      if (value.includes('\x04')) {
        value = msgid;
      }
      return value;
    };

    django.npgettext = function(context, singular, plural, count) {
      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
      if (value.includes('\x04')) {
        value = django.ngettext(singular, plural, count);
      }
      return value;
    };

    django.interpolate = function(fmt, obj, named) {
      if (named) {
        return fmt.replace(/%\(\w+\)s/g, function(match){return String(obj[match.slice(2,-2)])});
      } else {
        return fmt.replace(/%s/g, function(match){return String(obj.shift())});
      }
    };


    /* formatting library */

    django.formats = {
    "DATETIME_FORMAT": "Y. F j. H:i",
    "DATETIME_INPUT_FORMATS": [
      "%Y.%m.%d. %H:%M:%S",
      "%Y.%m.%d. %H:%M:%S.%f",
      "%Y.%m.%d. %H:%M",
      "%Y-%m-%d %H:%M:%S",
      "%Y-%m-%d %H:%M:%S.%f",
      "%Y-%m-%d %H:%M",
      "%Y-%m-%d"
    ],
    "DATE_FORMAT": "Y. F j.",
    "DATE_INPUT_FORMATS": [
      "%Y.%m.%d.",
      "%Y-%m-%d"
    ],
    "DECIMAL_SEPARATOR": ",",
    "FIRST_DAY_OF_WEEK": 1,
    "MONTH_DAY_FORMAT": "F j.",
    "NUMBER_GROUPING": 3,
    "SHORT_DATETIME_FORMAT": "Y.m.d. H:i",
    "SHORT_DATE_FORMAT": "Y.m.d.",
    "THOUSAND_SEPARATOR": "\u00a0",
    "TIME_FORMAT": "H:i",
    "TIME_INPUT_FORMATS": [
      "%H:%M:%S",
      "%H:%M",
      "%H:%M:%S.%f"
    ],
    "YEAR_MONTH_FORMAT": "Y. F"
  };

    django.get_format = function(format_type) {
      const value = django.formats[format_type];
      if (typeof value === 'undefined') {
        return format_type;
      } else {
        return value;
      }
    };

    /* add to global namespace */
    globals.pluralidx = django.pluralidx;
    globals.gettext = django.gettext;
    globals.ngettext = django.ngettext;
    globals.gettext_noop = django.gettext_noop;
    globals.pgettext = django.pgettext;
    globals.npgettext = django.npgettext;
    globals.interpolate = django.interpolate;
    globals.get_format = django.get_format;

    django.jsi18n_initialized = true;
  }
};

